<?php

declare(strict_types=1);

namespace App\Enum;

use App\Entity\SystemConfig;

/**
 * Enum for system setting keys
 */
enum SystemSettingKey: string
{
    case STOCK_ADJUSTMENT_LOOKBACK_ORDERS = 'stock_adjustment_lookback_orders';
    case DEFAULT_WANTED_STOCK = 'default_wanted_stock';
    case SYSTEM_NAME = 'system_name';
    case STOCK_INCREASE_AMOUNT = 'stock_increase_amount';
    case STOCK_DECREASE_AMOUNT = 'stock_decrease_amount';
    case STOCK_LOW_MULTIPLIER = 'stock_low_multiplier';

    public function defaultValue(): string
    {
        return match ($this) {
            self::STOCK_ADJUSTMENT_LOOKBACK_ORDERS => SystemConfig::DEFAULT_STOCK_ADJUSTMENT_LOOKBACK_ORDERS,
            self::DEFAULT_WANTED_STOCK => SystemConfig::DEFAULT_DEFAULT_WANTED_STOCK,
            self::SYSTEM_NAME => SystemConfig::DEFAULT_SYSTEM_NAME,
            self::STOCK_INCREASE_AMOUNT => SystemConfig::DEFAULT_STOCK_INCREASE_AMOUNT,
            self::STOCK_DECREASE_AMOUNT => SystemConfig::DEFAULT_STOCK_DECREASE_AMOUNT,
            self::STOCK_LOW_MULTIPLIER => SystemConfig::DEFAULT_STOCK_LOW_MULTIPLIER,
        };
    }

    public function defaultDescription(): string
    {
        return match ($this) {
            self::STOCK_ADJUSTMENT_LOOKBACK_ORDERS => SystemConfig::STOCK_ADJUSTMENT_LOOKBACK_ORDERS_DESCRIPTION,
            self::DEFAULT_WANTED_STOCK => SystemConfig::DEFAULT_DEFAULT_WANTED_STOCK_DESCRIPTION,
            self::SYSTEM_NAME => SystemConfig::DEFAULT_SYSTEM_NAME_DESCRIPTION,
            self::STOCK_INCREASE_AMOUNT => SystemConfig::DEFAULT_STOCK_INCREASE_AMOUNT_DESCRIPTION,
            self::STOCK_DECREASE_AMOUNT => SystemConfig::DEFAULT_STOCK_DECREASE_AMOUNT_DESCRIPTION,
            self::STOCK_LOW_MULTIPLIER => SystemConfig::DEFAULT_STOCK_LOW_MULTIPLIER_DESCRIPTION,
        };
    }
}
